@@ -3,7 +3,8 @@
 // Use of this source code is governed by a BSD-style
 // license that can be found in the LICENSE file.
 
-// The tokenauth command demonstrates using the oauth2.StaticTokenSource.
+// The tokenauth command demonstrates using a Personal Access Token (PAT) to
+// authenticate with GitHub.
 // You can test out a GitHub Personal Access Token using this simple example.
 // You can generate them here: https://github.com/settings/tokens
 package main
@@ -12,26 +13,20 @@ import (
 	"context"
 	"fmt"
 	"log"
-	"syscall"
+	"os"
 
-	"github.com/google/go-github/v48/github"
-	"golang.org/x/crypto/ssh/terminal"
-	"golang.org/x/oauth2"
+	"github.com/google/go-github/v60/github"
+	"golang.org/x/term"
 )
 
 func main() {
 	fmt.Print("GitHub Token: ")
-	byteToken, _ := terminal.ReadPassword(int(syscall.Stdin))
+	byteToken, _ := term.ReadPassword(int(os.Stdin.Fd()))
 	println()
 	token := string(byteToken)
 
 	ctx := context.Background()
-	ts := oauth2.StaticTokenSource(
-		&oauth2.Token{AccessToken: token},
-	)
-	tc := oauth2.NewClient(ctx, ts)
-
-	client := github.NewClient(tc)
+	client := github.NewClient(nil).WithAuthToken(token)
 
 	user, resp, err := client.Users.Get(ctx, "")
 	if err != nil {
