@@ -25,7 +25,7 @@ func TestAdminOrgs_Create(t *testing.T) {
 
 	mux.HandleFunc("/admin/organizations", func(w http.ResponseWriter, r *http.Request) {
 		v := new(createOrgRequest)
-		json.NewDecoder(r.Body).Decode(v)
+		assertNilError(t, json.NewDecoder(r.Body).Decode(v))
 
 		testMethod(t, r, "POST")
 		want := &createOrgRequest{Login: String("github"), Admin: String("ghAdmin")}
@@ -67,7 +67,7 @@ func TestAdminOrgs_Rename(t *testing.T) {
 
 	mux.HandleFunc("/admin/organizations/o", func(w http.ResponseWriter, r *http.Request) {
 		v := new(renameOrgRequest)
-		json.NewDecoder(r.Body).Decode(v)
+		assertNilError(t, json.NewDecoder(r.Body).Decode(v))
 
 		testMethod(t, r, "PATCH")
 		want := &renameOrgRequest{Login: String("the-new-octocats")}
@@ -105,7 +105,7 @@ func TestAdminOrgs_RenameByName(t *testing.T) {
 
 	mux.HandleFunc("/admin/organizations/o", func(w http.ResponseWriter, r *http.Request) {
 		v := new(renameOrgRequest)
-		json.NewDecoder(r.Body).Decode(v)
+		assertNilError(t, json.NewDecoder(r.Body).Decode(v))
 
 		testMethod(t, r, "PATCH")
 		want := &renameOrgRequest{Login: String("the-new-octocats")}
