@@ -21,7 +21,7 @@ func TestChecksService_GetCheckRun(t *testing.T) {
 
 	mux.HandleFunc("/repos/o/r/check-runs/1", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, "GET")
-
+		testHeader(t, r, "Accept", mediaTypeCheckRunsPreview)
 		fmt.Fprint(w, `{
 			"id": 1,
                         "name":"testCheckRun",
@@ -71,7 +71,7 @@ func TestChecksService_GetCheckSuite(t *testing.T) {
 
 	mux.HandleFunc("/repos/o/r/check-suites/1", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, "GET")
-
+		testHeader(t, r, "Accept", mediaTypeCheckRunsPreview)
 		fmt.Fprint(w, `{
 			"id": 1,
                         "head_branch":"master",
@@ -120,7 +120,7 @@ func TestChecksService_CreateCheckRun(t *testing.T) {
 
 	mux.HandleFunc("/repos/o/r/check-runs", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, "POST")
-
+		testHeader(t, r, "Accept", mediaTypeCheckRunsPreview)
 		fmt.Fprint(w, `{
 			"id": 1,
                         "name":"testCreateCheckRun",
@@ -187,7 +187,7 @@ func TestChecksService_ListCheckRunAnnotations(t *testing.T) {
 
 	mux.HandleFunc("/repos/o/r/check-runs/1/annotations", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, "GET")
-
+		testHeader(t, r, "Accept", mediaTypeCheckRunsPreview)
 		testFormValues(t, r, values{
 			"page": "1",
 		})
@@ -247,7 +247,7 @@ func TestChecksService_UpdateCheckRun(t *testing.T) {
 
 	mux.HandleFunc("/repos/o/r/check-runs/1", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, "PATCH")
-
+		testHeader(t, r, "Accept", mediaTypeCheckRunsPreview)
 		fmt.Fprint(w, `{
 			"id": 1,
                         "name":"testUpdateCheckRun",
@@ -313,12 +313,13 @@ func TestChecksService_ListCheckRunsForRef(t *testing.T) {
 
 	mux.HandleFunc("/repos/o/r/commits/master/check-runs", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, "GET")
-
+		testHeader(t, r, "Accept", mediaTypeCheckRunsPreview)
 		testFormValues(t, r, values{
 			"check_name": "testing",
 			"page":       "1",
 			"status":     "completed",
 			"filter":     "all",
+			"app_id":     "1",
 		})
 		fmt.Fprint(w, `{"total_count":1,
                                 "check_runs": [{
@@ -327,7 +328,9 @@ func TestChecksService_ListCheckRunsForRef(t *testing.T) {
                                     "status": "completed",
                                     "conclusion": "neutral",
                                     "started_at": "2018-05-04T01:14:52Z",
-                                    "completed_at": "2018-05-04T01:14:52Z"}]}`,
+                                    "completed_at": "2018-05-04T01:14:52Z",
+                                    "app": {
+                                      "id": 1}}]}`,
 		)
 	})
 
@@ -335,6 +338,7 @@ func TestChecksService_ListCheckRunsForRef(t *testing.T) {
 		CheckName:   String("testing"),
 		Status:      String("completed"),
 		Filter:      String("all"),
+		AppID:       Int64(1),
 		ListOptions: ListOptions{Page: 1},
 	}
 	ctx := context.Background()
@@ -352,6 +356,7 @@ func TestChecksService_ListCheckRunsForRef(t *testing.T) {
 			CompletedAt: &Timestamp{startedAt},
 			Conclusion:  String("neutral"),
 			HeadSHA:     String("deadbeef"),
+			App:         &App{ID: Int64(1)},
 		}},
 	}
 
@@ -380,7 +385,7 @@ func TestChecksService_ListCheckRunsCheckSuite(t *testing.T) {
 
 	mux.HandleFunc("/repos/o/r/check-suites/1/check-runs", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, "GET")
-
+		testHeader(t, r, "Accept", mediaTypeCheckRunsPreview)
 		testFormValues(t, r, values{
 			"check_name": "testing",
 			"page":       "1",
@@ -447,7 +452,7 @@ func TestChecksService_ListCheckSuiteForRef(t *testing.T) {
 
 	mux.HandleFunc("/repos/o/r/commits/master/check-suites", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, "GET")
-
+		testHeader(t, r, "Accept", mediaTypeCheckRunsPreview)
 		testFormValues(t, r, values{
 			"check_name": "testing",
 			"page":       "1",
@@ -513,7 +518,7 @@ func TestChecksService_SetCheckSuitePreferences(t *testing.T) {
 
 	mux.HandleFunc("/repos/o/r/check-suites/preferences", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, "PATCH")
-
+		testHeader(t, r, "Accept", mediaTypeCheckRunsPreview)
 		testBody(t, r, `{"auto_trigger_checks":[{"app_id":2,"setting":false}]}`+"\n")
 		fmt.Fprint(w, `{"preferences":{"auto_trigger_checks":[{"app_id": 2,"setting": false}]}}`)
 	})
@@ -560,7 +565,7 @@ func TestChecksService_CreateCheckSuite(t *testing.T) {
 
 	mux.HandleFunc("/repos/o/r/check-suites", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, "POST")
-
+		testHeader(t, r, "Accept", mediaTypeCheckRunsPreview)
 		fmt.Fprint(w, `{
 			"id": 2,
                         "head_branch":"master",
@@ -616,7 +621,7 @@ func TestChecksService_ReRequestCheckSuite(t *testing.T) {
 
 	mux.HandleFunc("/repos/o/r/check-suites/1/rerequest", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, "POST")
-
+		testHeader(t, r, "Accept", mediaTypeCheckRunsPreview)
 		w.WriteHeader(http.StatusCreated)
 	})
 	ctx := context.Background()
@@ -1713,3 +1718,28 @@ func TestCheckSuitePreferenceResults_Marshal(t *testing.T) {
 
 	testJSONMarshal(t, u, want)
 }
+
+func TestChecksService_ReRequestCheckRun(t *testing.T) {
+	client, mux, _, teardown := setup()
+	defer teardown()
+
+	mux.HandleFunc("/repos/o/r/check-runs/1/rerequest", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, "POST")
+		testHeader(t, r, "Accept", mediaTypeCheckRunsPreview)
+		w.WriteHeader(http.StatusCreated)
+	})
+	ctx := context.Background()
+	resp, err := client.Checks.ReRequestCheckRun(ctx, "o", "r", 1)
+	if err != nil {
+		t.Errorf("Checks.ReRequestCheckRun return error: %v", err)
+	}
+	if got, want := resp.StatusCode, http.StatusCreated; got != want {
+		t.Errorf("Checks.ReRequestCheckRun = %v, want %v", got, want)
+	}
+
+	const methodName = "ReRequestCheckRun"
+	testBadOptions(t, methodName, func() (err error) {
+		_, err = client.Checks.ReRequestCheckRun(ctx, "\n", "\n", 1)
+		return err
+	})
+}
