@@ -12,17 +12,17 @@ import (
 	"fmt"
 	"log"
 
-	"github.com/google/go-github/v48/github"
+	"github.com/google/go-github/v60/github"
 )
 
-func ExampleClient_Markdown() {
+func ExampleMarkdownService_Render() {
 	client := github.NewClient(nil)
 
 	input := "# heading #\n\nLink to issue #1"
 	opt := &github.MarkdownOptions{Mode: "gfm", Context: "google/go-github"}
 
 	ctx := context.Background()
-	output, _, err := client.Markdown(ctx, input, opt)
+	output, _, err := client.Markdown.Render(ctx, input, opt)
 	if err != nil {
 		fmt.Println(err)
 	}
@@ -49,14 +49,14 @@ func ExampleRepositoriesService_GetReadme() {
 	fmt.Printf("google/go-github README:\n%v\n", content)
 }
 
-func ExampleRepositoriesService_List() {
+func ExampleRepositoriesService_ListByUser() {
 	client := github.NewClient(nil)
 
 	user := "willnorris"
-	opt := &github.RepositoryListOptions{Type: "owner", Sort: "updated", Direction: "desc"}
+	opt := &github.RepositoryListByUserOptions{Type: "owner", Sort: "updated", Direction: "desc"}
 
 	ctx := context.Background()
-	repos, _, err := client.Repositories.List(ctx, user, opt)
+	repos, _, err := client.Repositories.ListByUser(ctx, user, opt)
 	if err != nil {
 		fmt.Println(err)
 	}
