@@ -56,7 +56,7 @@ func TestOrganizationsService_EditActionsAllowed(t *testing.T) {
 
 	mux.HandleFunc("/orgs/o/actions/permissions/selected-actions", func(w http.ResponseWriter, r *http.Request) {
 		v := new(ActionsAllowed)
-		json.NewDecoder(r.Body).Decode(v)
+		assertNilError(t, json.NewDecoder(r.Body).Decode(v))
 
 		testMethod(t, r, "PUT")
 		if !cmp.Equal(v, input) {
@@ -91,41 +91,3 @@ func TestOrganizationsService_EditActionsAllowed(t *testing.T) {
 		return resp, err
 	})
 }
-
-func TestActionsAllowed_Marshal(t *testing.T) {
-	testJSONMarshal(t, &ActionsAllowed{}, "{}")
-
-	u := &ActionsAllowed{
-		GithubOwnedAllowed: Bool(false),
-		VerifiedAllowed:    Bool(false),
-		PatternsAllowed:    []string{"s"},
-	}
-
-	want := `{
-		"github_owned_allowed": false,
-		"verified_allowed": false,
-		"patterns_allowed": [
-			"s"
-		]
-	}`
-
-	testJSONMarshal(t, u, want)
-}
-
-func TestActionsPermissions_Marshal(t *testing.T) {
-	testJSONMarshal(t, &ActionsPermissions{}, "{}")
-
-	u := &ActionsPermissions{
-		EnabledRepositories: String("e"),
-		AllowedActions:      String("a"),
-		SelectedActionsURL:  String("sau"),
-	}
-
-	want := `{
-		"enabled_repositories": "e",
-		"allowed_actions": "a",
-		"selected_actions_url": "sau"
-	}`
-
-	testJSONMarshal(t, u, want)
-}
