@@ -13,23 +13,25 @@ import (
 // ProjectsService provides access to the projects functions in the
 // GitHub API.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/
+// GitHub API docs: https://docs.github.com/rest/projects
 type ProjectsService service
 
 // Project represents a GitHub Project.
 type Project struct {
-	ID         *int64     `json:"id,omitempty"`
-	URL        *string    `json:"url,omitempty"`
-	HTMLURL    *string    `json:"html_url,omitempty"`
-	ColumnsURL *string    `json:"columns_url,omitempty"`
-	OwnerURL   *string    `json:"owner_url,omitempty"`
-	Name       *string    `json:"name,omitempty"`
-	Body       *string    `json:"body,omitempty"`
-	Number     *int       `json:"number,omitempty"`
-	State      *string    `json:"state,omitempty"`
-	CreatedAt  *Timestamp `json:"created_at,omitempty"`
-	UpdatedAt  *Timestamp `json:"updated_at,omitempty"`
-	NodeID     *string    `json:"node_id,omitempty"`
+	ID                     *int64     `json:"id,omitempty"`
+	URL                    *string    `json:"url,omitempty"`
+	HTMLURL                *string    `json:"html_url,omitempty"`
+	ColumnsURL             *string    `json:"columns_url,omitempty"`
+	OwnerURL               *string    `json:"owner_url,omitempty"`
+	Name                   *string    `json:"name,omitempty"`
+	Body                   *string    `json:"body,omitempty"`
+	Number                 *int       `json:"number,omitempty"`
+	State                  *string    `json:"state,omitempty"`
+	CreatedAt              *Timestamp `json:"created_at,omitempty"`
+	UpdatedAt              *Timestamp `json:"updated_at,omitempty"`
+	NodeID                 *string    `json:"node_id,omitempty"`
+	OrganizationPermission *string    `json:"organization_permission,omitempty"`
+	Private                *bool      `json:"private,omitempty"`
 
 	// The User object that generated the project.
 	Creator *User `json:"creator,omitempty"`
@@ -41,7 +43,9 @@ func (p Project) String() string {
 
 // GetProject gets a GitHub Project for a repo.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#get-a-project
+// GitHub API docs: https://docs.github.com/rest/projects/projects#get-a-project
+//
+//meta:operation GET /projects/{project_id}
 func (s *ProjectsService) GetProject(ctx context.Context, id int64) (*Project, *Response, error) {
 	u := fmt.Sprintf("projects/%v", id)
 	req, err := s.client.NewRequest("GET", u, nil)
@@ -83,12 +87,14 @@ type ProjectOptions struct {
 	// Sets visibility of the project within the organization.
 	// Setting visibility is only available
 	// for organization projects.(Optional.)
-	Public *bool `json:"public,omitempty"`
+	Private *bool `json:"private,omitempty"`
 }
 
 // UpdateProject updates a repository project.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#update-a-project
+// GitHub API docs: https://docs.github.com/rest/projects/projects#update-a-project
+//
+//meta:operation PATCH /projects/{project_id}
 func (s *ProjectsService) UpdateProject(ctx context.Context, id int64, opts *ProjectOptions) (*Project, *Response, error) {
 	u := fmt.Sprintf("projects/%v", id)
 	req, err := s.client.NewRequest("PATCH", u, opts)
@@ -110,7 +116,9 @@ func (s *ProjectsService) UpdateProject(ctx context.Context, id int64, opts *Pro
 
 // DeleteProject deletes a GitHub Project from a repository.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#delete-a-project
+// GitHub API docs: https://docs.github.com/rest/projects/projects#delete-a-project
+//
+//meta:operation DELETE /projects/{project_id}
 func (s *ProjectsService) DeleteProject(ctx context.Context, id int64) (*Response, error) {
 	u := fmt.Sprintf("projects/%v", id)
 	req, err := s.client.NewRequest("DELETE", u, nil)
@@ -126,7 +134,7 @@ func (s *ProjectsService) DeleteProject(ctx context.Context, id int64) (*Respons
 
 // ProjectColumn represents a column of a GitHub Project.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/repos/projects/
+// GitHub API docs: https://docs.github.com/rest/repos/projects/
 type ProjectColumn struct {
 	ID         *int64     `json:"id,omitempty"`
 	Name       *string    `json:"name,omitempty"`
@@ -140,7 +148,9 @@ type ProjectColumn struct {
 
 // ListProjectColumns lists the columns of a GitHub Project for a repo.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#list-project-columns
+// GitHub API docs: https://docs.github.com/rest/projects/columns#list-project-columns
+//
+//meta:operation GET /projects/{project_id}/columns
 func (s *ProjectsService) ListProjectColumns(ctx context.Context, projectID int64, opts *ListOptions) ([]*ProjectColumn, *Response, error) {
 	u := fmt.Sprintf("projects/%v/columns", projectID)
 	u, err := addOptions(u, opts)
@@ -167,7 +177,9 @@ func (s *ProjectsService) ListProjectColumns(ctx context.Context, projectID int6
 
 // GetProjectColumn gets a column of a GitHub Project for a repo.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#get-a-project-column
+// GitHub API docs: https://docs.github.com/rest/projects/columns#get-a-project-column
+//
+//meta:operation GET /projects/columns/{column_id}
 func (s *ProjectsService) GetProjectColumn(ctx context.Context, id int64) (*ProjectColumn, *Response, error) {
 	u := fmt.Sprintf("projects/columns/%v", id)
 	req, err := s.client.NewRequest("GET", u, nil)
@@ -197,7 +209,9 @@ type ProjectColumnOptions struct {
 
 // CreateProjectColumn creates a column for the specified (by number) project.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#create-a-project-column
+// GitHub API docs: https://docs.github.com/rest/projects/columns#create-a-project-column
+//
+//meta:operation POST /projects/{project_id}/columns
 func (s *ProjectsService) CreateProjectColumn(ctx context.Context, projectID int64, opts *ProjectColumnOptions) (*ProjectColumn, *Response, error) {
 	u := fmt.Sprintf("projects/%v/columns", projectID)
 	req, err := s.client.NewRequest("POST", u, opts)
@@ -219,7 +233,9 @@ func (s *ProjectsService) CreateProjectColumn(ctx context.Context, projectID int
 
 // UpdateProjectColumn updates a column of a GitHub Project.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#update-an-existing-project-column
+// GitHub API docs: https://docs.github.com/rest/projects/columns#update-an-existing-project-column
+//
+//meta:operation PATCH /projects/columns/{column_id}
 func (s *ProjectsService) UpdateProjectColumn(ctx context.Context, columnID int64, opts *ProjectColumnOptions) (*ProjectColumn, *Response, error) {
 	u := fmt.Sprintf("projects/columns/%v", columnID)
 	req, err := s.client.NewRequest("PATCH", u, opts)
@@ -241,7 +257,9 @@ func (s *ProjectsService) UpdateProjectColumn(ctx context.Context, columnID int6
 
 // DeleteProjectColumn deletes a column from a GitHub Project.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#delete-a-project-column
+// GitHub API docs: https://docs.github.com/rest/projects/columns#delete-a-project-column
+//
+//meta:operation DELETE /projects/columns/{column_id}
 func (s *ProjectsService) DeleteProjectColumn(ctx context.Context, columnID int64) (*Response, error) {
 	u := fmt.Sprintf("projects/columns/%v", columnID)
 	req, err := s.client.NewRequest("DELETE", u, nil)
@@ -265,7 +283,9 @@ type ProjectColumnMoveOptions struct {
 
 // MoveProjectColumn moves a column within a GitHub Project.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#move-a-project-column
+// GitHub API docs: https://docs.github.com/rest/projects/columns#move-a-project-column
+//
+//meta:operation POST /projects/columns/{column_id}/moves
 func (s *ProjectsService) MoveProjectColumn(ctx context.Context, columnID int64, opts *ProjectColumnMoveOptions) (*Response, error) {
 	u := fmt.Sprintf("projects/columns/%v/moves", columnID)
 	req, err := s.client.NewRequest("POST", u, opts)
@@ -281,7 +301,7 @@ func (s *ProjectsService) MoveProjectColumn(ctx context.Context, columnID int64,
 
 // ProjectCard represents a card in a column of a GitHub Project.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/cards/#get-a-project-card
+// GitHub API docs: https://docs.github.com/rest/projects/cards/#get-a-project-card
 type ProjectCard struct {
 	URL        *string    `json:"url,omitempty"`
 	ColumnURL  *string    `json:"column_url,omitempty"`
@@ -316,7 +336,9 @@ type ProjectCardListOptions struct {
 
 // ListProjectCards lists the cards in a column of a GitHub Project.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#list-project-cards
+// GitHub API docs: https://docs.github.com/rest/projects/cards#list-project-cards
+//
+//meta:operation GET /projects/columns/{column_id}/cards
 func (s *ProjectsService) ListProjectCards(ctx context.Context, columnID int64, opts *ProjectCardListOptions) ([]*ProjectCard, *Response, error) {
 	u := fmt.Sprintf("projects/columns/%v/cards", columnID)
 	u, err := addOptions(u, opts)
@@ -343,7 +365,9 @@ func (s *ProjectsService) ListProjectCards(ctx context.Context, columnID int64,
 
 // GetProjectCard gets a card in a column of a GitHub Project.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#get-a-project-card
+// GitHub API docs: https://docs.github.com/rest/projects/cards#get-a-project-card
+//
+//meta:operation GET /projects/columns/cards/{card_id}
 func (s *ProjectsService) GetProjectCard(ctx context.Context, cardID int64) (*ProjectCard, *Response, error) {
 	u := fmt.Sprintf("projects/columns/cards/%v", cardID)
 	req, err := s.client.NewRequest("GET", u, nil)
@@ -381,7 +405,9 @@ type ProjectCardOptions struct {
 
 // CreateProjectCard creates a card in the specified column of a GitHub Project.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#create-a-project-card
+// GitHub API docs: https://docs.github.com/rest/projects/cards#create-a-project-card
+//
+//meta:operation POST /projects/columns/{column_id}/cards
 func (s *ProjectsService) CreateProjectCard(ctx context.Context, columnID int64, opts *ProjectCardOptions) (*ProjectCard, *Response, error) {
 	u := fmt.Sprintf("projects/columns/%v/cards", columnID)
 	req, err := s.client.NewRequest("POST", u, opts)
@@ -403,7 +429,9 @@ func (s *ProjectsService) CreateProjectCard(ctx context.Context, columnID int64,
 
 // UpdateProjectCard updates a card of a GitHub Project.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#update-an-existing-project-card
+// GitHub API docs: https://docs.github.com/rest/projects/cards#update-an-existing-project-card
+//
+//meta:operation PATCH /projects/columns/cards/{card_id}
 func (s *ProjectsService) UpdateProjectCard(ctx context.Context, cardID int64, opts *ProjectCardOptions) (*ProjectCard, *Response, error) {
 	u := fmt.Sprintf("projects/columns/cards/%v", cardID)
 	req, err := s.client.NewRequest("PATCH", u, opts)
@@ -425,7 +453,9 @@ func (s *ProjectsService) UpdateProjectCard(ctx context.Context, cardID int64, o
 
 // DeleteProjectCard deletes a card from a GitHub Project.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#delete-a-project-card
+// GitHub API docs: https://docs.github.com/rest/projects/cards#delete-a-project-card
+//
+//meta:operation DELETE /projects/columns/cards/{card_id}
 func (s *ProjectsService) DeleteProjectCard(ctx context.Context, cardID int64) (*Response, error) {
 	u := fmt.Sprintf("projects/columns/cards/%v", cardID)
 	req, err := s.client.NewRequest("DELETE", u, nil)
@@ -453,7 +483,9 @@ type ProjectCardMoveOptions struct {
 
 // MoveProjectCard moves a card within a GitHub Project.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#move-a-project-card
+// GitHub API docs: https://docs.github.com/rest/projects/cards#move-a-project-card
+//
+//meta:operation POST /projects/columns/cards/{card_id}/moves
 func (s *ProjectsService) MoveProjectCard(ctx context.Context, cardID int64, opts *ProjectCardMoveOptions) (*Response, error) {
 	u := fmt.Sprintf("projects/columns/cards/%v/moves", cardID)
 	req, err := s.client.NewRequest("POST", u, opts)
@@ -483,7 +515,9 @@ type ProjectCollaboratorOptions struct {
 // AddProjectCollaborator adds a collaborator to an organization project and sets
 // their permission level. You must be an organization owner or a project admin to add a collaborator.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#add-project-collaborator
+// GitHub API docs: https://docs.github.com/rest/projects/collaborators#add-project-collaborator
+//
+//meta:operation PUT /projects/{project_id}/collaborators/{username}
 func (s *ProjectsService) AddProjectCollaborator(ctx context.Context, id int64, username string, opts *ProjectCollaboratorOptions) (*Response, error) {
 	u := fmt.Sprintf("projects/%v/collaborators/%v", id, username)
 	req, err := s.client.NewRequest("PUT", u, opts)
@@ -500,7 +534,9 @@ func (s *ProjectsService) AddProjectCollaborator(ctx context.Context, id int64,
 // RemoveProjectCollaborator removes a collaborator from an organization project.
 // You must be an organization owner or a project admin to remove a collaborator.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#remove-user-as-a-collaborator
+// GitHub API docs: https://docs.github.com/rest/projects/collaborators#remove-user-as-a-collaborator
+//
+//meta:operation DELETE /projects/{project_id}/collaborators/{username}
 func (s *ProjectsService) RemoveProjectCollaborator(ctx context.Context, id int64, username string) (*Response, error) {
 	u := fmt.Sprintf("projects/%v/collaborators/%v", id, username)
 	req, err := s.client.NewRequest("DELETE", u, nil)
@@ -536,7 +572,9 @@ type ListCollaboratorOptions struct {
 // with access through default organization permissions, and organization owners. You must be an
 // organization owner or a project admin to list collaborators.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#list-project-collaborators
+// GitHub API docs: https://docs.github.com/rest/projects/collaborators#list-project-collaborators
+//
+//meta:operation GET /projects/{project_id}/collaborators
 func (s *ProjectsService) ListProjectCollaborators(ctx context.Context, id int64, opts *ListCollaboratorOptions) ([]*User, *Response, error) {
 	u := fmt.Sprintf("projects/%v/collaborators", id)
 	u, err := addOptions(u, opts)
@@ -574,7 +612,9 @@ type ProjectPermissionLevel struct {
 // project. Possible values for the permission key: "admin", "write", "read", "none".
 // You must be an organization owner or a project admin to review a user's permission level.
 //
-// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/projects/#get-project-permission-for-a-user
+// GitHub API docs: https://docs.github.com/rest/projects/collaborators#get-project-permission-for-a-user
+//
+//meta:operation GET /projects/{project_id}/collaborators/{username}/permission
 func (s *ProjectsService) ReviewProjectCollaboratorPermission(ctx context.Context, id int64, username string) (*ProjectPermissionLevel, *Response, error) {
 	u := fmt.Sprintf("projects/%v/collaborators/%v/permission", id, username)
 	req, err := s.client.NewRequest("GET", u, nil)
