@@ -15,7 +15,6 @@ import (
 	"testing"
 
 	"github.com/google/go-cmp/cmp"
-	"golang.org/x/crypto/openpgp"
 )
 
 func TestRepositoryContent_GetContent(t *testing.T) {
@@ -54,6 +53,12 @@ func TestRepositoryContent_GetContent(t *testing.T) {
 			want:     "",
 			wantErr:  true,
 		},
+		{
+			encoding: String("none"),
+			content:  nil,
+			want:     "",
+			wantErr:  true,
+		},
 	}
 
 	for _, tt := range tests {
@@ -465,6 +470,20 @@ func TestRepositoriesService_GetContents_DirectoryWithSpaces(t *testing.T) {
 	}
 }
 
+func TestRepositoriesService_GetContents_PathWithParent(t *testing.T) {
+	client, mux, _, teardown := setup()
+	defer teardown()
+	mux.HandleFunc("/repos/o/r/contents/some/../directory/file.go", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, "GET")
+		fmt.Fprint(w, `{}`)
+	})
+	ctx := context.Background()
+	_, _, _, err := client.Repositories.GetContents(ctx, "o", "r", "some/../directory/file.go", &RepositoryContentGetOptions{})
+	if err == nil {
+		t.Fatal("Repositories.GetContents expected error but got none")
+	}
+}
+
 func TestRepositoriesService_GetContents_DirectoryWithPlusChars(t *testing.T) {
 	client, mux, _, teardown := setup()
 	defer teardown()
@@ -675,7 +694,7 @@ func TestRepositoriesService_GetArchiveLink(t *testing.T) {
 		http.Redirect(w, r, "http://github.com/a", http.StatusFound)
 	})
 	ctx := context.Background()
-	url, resp, err := client.Repositories.GetArchiveLink(ctx, "o", "r", Tarball, &RepositoryContentGetOptions{Ref: "yo"}, true)
+	url, resp, err := client.Repositories.GetArchiveLink(ctx, "o", "r", Tarball, &RepositoryContentGetOptions{Ref: "yo"}, 1)
 	if err != nil {
 		t.Errorf("Repositories.GetArchiveLink returned error: %v", err)
 	}
@@ -689,7 +708,7 @@ func TestRepositoriesService_GetArchiveLink(t *testing.T) {
 
 	const methodName = "GetArchiveLink"
 	testBadOptions(t, methodName, func() (err error) {
-		_, _, err = client.Repositories.GetArchiveLink(ctx, "\n", "\n", Tarball, &RepositoryContentGetOptions{}, true)
+		_, _, err = client.Repositories.GetArchiveLink(ctx, "\n", "\n", Tarball, &RepositoryContentGetOptions{}, 1)
 		return err
 	})
 
@@ -698,7 +717,7 @@ func TestRepositoriesService_GetArchiveLink(t *testing.T) {
 		return nil, errors.New("failed to get archive link")
 	})
 	testBadOptions(t, methodName, func() (err error) {
-		_, _, err = client.Repositories.GetArchiveLink(ctx, "o", "r", Tarball, &RepositoryContentGetOptions{}, true)
+		_, _, err = client.Repositories.GetArchiveLink(ctx, "o", "r", Tarball, &RepositoryContentGetOptions{}, 1)
 		return err
 	})
 }
@@ -711,7 +730,7 @@ func TestRepositoriesService_GetArchiveLink_StatusMovedPermanently_dontFollowRed
 		http.Redirect(w, r, "http://github.com/a", http.StatusMovedPermanently)
 	})
 	ctx := context.Background()
-	_, resp, _ := client.Repositories.GetArchiveLink(ctx, "o", "r", Tarball, &RepositoryContentGetOptions{}, false)
+	_, resp, _ := client.Repositories.GetArchiveLink(ctx, "o", "r", Tarball, &RepositoryContentGetOptions{}, 0)
 	if resp.StatusCode != http.StatusMovedPermanently {
 		t.Errorf("Repositories.GetArchiveLink returned status: %d, want %d", resp.StatusCode, http.StatusMovedPermanently)
 	}
@@ -731,7 +750,7 @@ func TestRepositoriesService_GetArchiveLink_StatusMovedPermanently_followRedirec
 		http.Redirect(w, r, "http://github.com/a", http.StatusFound)
 	})
 	ctx := context.Background()
-	url, resp, err := client.Repositories.GetArchiveLink(ctx, "o", "r", Tarball, &RepositoryContentGetOptions{}, true)
+	url, resp, err := client.Repositories.GetArchiveLink(ctx, "o", "r", Tarball, &RepositoryContentGetOptions{}, 1)
 	if err != nil {
 		t.Errorf("Repositories.GetArchiveLink returned error: %v", err)
 	}
@@ -744,23 +763,6 @@ func TestRepositoriesService_GetArchiveLink_StatusMovedPermanently_followRedirec
 	}
 }
 
-func TestRepositoriesService_GetArchiveLink_invalidLocationHeader(t *testing.T) {
-	client, mux, _, teardown := setup()
-	defer teardown()
-
-	mux.HandleFunc("/repos/o/r/tarball", func(w http.ResponseWriter, r *http.Request) {
-		testMethod(t, r, "GET")
-		ctlChar := 0x7f
-		badURL := "https://google.com" + string(byte(ctlChar))
-		w.Header().Add("Location", badURL)
-		w.WriteHeader(http.StatusFound)
-	})
-
-	ctx := context.Background()
-	_, _, err := client.Repositories.GetArchiveLink(ctx, "o", "r", Tarball, &RepositoryContentGetOptions{}, false)
-	testURLParseError(t, err)
-}
-
 func TestRepositoriesService_GetContents_NoTrailingSlashInDirectoryApiPath(t *testing.T) {
 	client, mux, _, teardown := setup()
 	defer teardown()
@@ -785,18 +787,19 @@ func TestRepositoryContent_Marshal(t *testing.T) {
 	testJSONMarshal(t, &RepositoryContent{}, "{}")
 
 	r := &RepositoryContent{
-		Type:        String("type"),
-		Target:      String("target"),
-		Encoding:    String("encoding"),
-		Size:        Int(1),
-		Name:        String("name"),
-		Path:        String("path"),
-		Content:     String("content"),
-		SHA:         String("sha"),
-		URL:         String("url"),
-		GitURL:      String("gurl"),
-		HTMLURL:     String("hurl"),
-		DownloadURL: String("durl"),
+		Type:            String("type"),
+		Target:          String("target"),
+		Encoding:        String("encoding"),
+		Size:            Int(1),
+		Name:            String("name"),
+		Path:            String("path"),
+		Content:         String("content"),
+		SHA:             String("sha"),
+		URL:             String("url"),
+		GitURL:          String("gurl"),
+		HTMLURL:         String("hurl"),
+		DownloadURL:     String("durl"),
+		SubmoduleGitURL: String("smgurl"),
 	}
 
 	want := `{
@@ -811,7 +814,8 @@ func TestRepositoryContent_Marshal(t *testing.T) {
 		"url": "url",
 		"git_url": "gurl",
 		"html_url": "hurl",
-		"download_url": "durl"
+		"download_url": "durl",
+		"submodule_git_url": "smgurl"
 	}`
 
 	testJSONMarshal(t, r, want)
@@ -822,29 +826,30 @@ func TestRepositoryContentResponse_Marshal(t *testing.T) {
 
 	r := &RepositoryContentResponse{
 		Content: &RepositoryContent{
-			Type:        String("type"),
-			Target:      String("target"),
-			Encoding:    String("encoding"),
-			Size:        Int(1),
-			Name:        String("name"),
-			Path:        String("path"),
-			Content:     String("content"),
-			SHA:         String("sha"),
-			URL:         String("url"),
-			GitURL:      String("gurl"),
-			HTMLURL:     String("hurl"),
-			DownloadURL: String("durl"),
+			Type:            String("type"),
+			Target:          String("target"),
+			Encoding:        String("encoding"),
+			Size:            Int(1),
+			Name:            String("name"),
+			Path:            String("path"),
+			Content:         String("content"),
+			SHA:             String("sha"),
+			URL:             String("url"),
+			GitURL:          String("gurl"),
+			HTMLURL:         String("hurl"),
+			DownloadURL:     String("durl"),
+			SubmoduleGitURL: String("smgurl"),
 		},
 		Commit: Commit{
 			SHA: String("s"),
 			Author: &CommitAuthor{
-				Date:  &referenceTime,
+				Date:  &Timestamp{referenceTime},
 				Name:  String("n"),
 				Email: String("e"),
 				Login: String("u"),
 			},
 			Committer: &CommitAuthor{
-				Date:  &referenceTime,
+				Date:  &Timestamp{referenceTime},
 				Name:  String("n"),
 				Email: String("e"),
 				Login: String("u"),
@@ -879,7 +884,6 @@ func TestRepositoryContentResponse_Marshal(t *testing.T) {
 			},
 			NodeID:       String("n"),
 			CommentCount: Int(1),
-			SigningKey:   &openpgp.Entity{},
 		},
 	}
 
@@ -896,7 +900,8 @@ func TestRepositoryContentResponse_Marshal(t *testing.T) {
 			"url": "url",
 			"git_url": "gurl",
 			"html_url": "hurl",
-			"download_url": "durl"
+			"download_url": "durl",
+			"submodule_git_url": "smgurl"
 		},
 		"commit": {
 			"sha": "s",
@@ -958,13 +963,13 @@ func TestRepositoryContentFileOptions_Marshal(t *testing.T) {
 		SHA:     String("type"),
 		Branch:  String("type"),
 		Author: &CommitAuthor{
-			Date:  &referenceTime,
+			Date:  &Timestamp{referenceTime},
 			Name:  String("name"),
 			Email: String("email"),
 			Login: String("login"),
 		},
 		Committer: &CommitAuthor{
-			Date:  &referenceTime,
+			Date:  &Timestamp{referenceTime},
 			Name:  String("name"),
 			Email: String("email"),
 			Login: String("login"),
