@@ -150,9 +150,11 @@ var hookDeliveryPayloadTypeToStruct = map[string]interface{}{
 	"content_reference":              &ContentReferenceEvent{},
 	"create":                         &CreateEvent{},
 	"delete":                         &DeleteEvent{},
+	"dependabot_alert":               &DependabotAlertEvent{},
 	"deploy_key":                     &DeployKeyEvent{},
 	"deployment":                     &DeploymentEvent{},
 	"deployment_status":              &DeploymentStatusEvent{},
+	"discussion_comment":             &DiscussionCommentEvent{},
 	"discussion":                     &DiscussionEvent{},
 	"fork":                           &ForkEvent{},
 	"github_app_authorization":       &GitHubAppAuthorizationEvent{},
@@ -175,6 +177,8 @@ var hookDeliveryPayloadTypeToStruct = map[string]interface{}{
 	"project":                        &ProjectEvent{},
 	"project_card":                   &ProjectCardEvent{},
 	"project_column":                 &ProjectColumnEvent{},
+	"projects_v2":                    &ProjectV2Event{},
+	"projects_v2_item":               &ProjectV2ItemEvent{},
 	"public":                         &PublicEvent{},
 	"pull_request":                   &PullRequestEvent{},
 	"pull_request_review":            &PullRequestReviewEvent{},
@@ -188,6 +192,8 @@ var hookDeliveryPayloadTypeToStruct = map[string]interface{}{
 	"repository_import":              &RepositoryImportEvent{},
 	"repository_vulnerability_alert": &RepositoryVulnerabilityAlertEvent{},
 	"secret_scanning_alert":          &SecretScanningAlertEvent{},
+	"security_advisory":              &SecurityAdvisoryEvent{},
+	"security_and_analysis":          &SecurityAndAnalysisEvent{},
 	"star":                           &StarEvent{},
 	"status":                         &StatusEvent{},
 	"team":                           &TeamEvent{},
