@@ -788,9 +788,9 @@ func TestIssuesSearchResult_Marshal(t *testing.T) {
 				Labels:            []*Label{{ID: Int64(1)}},
 				Assignee:          &User{ID: Int64(1)},
 				Comments:          Int(1),
-				ClosedAt:          &referenceTime,
-				CreatedAt:         &referenceTime,
-				UpdatedAt:         &referenceTime,
+				ClosedAt:          &Timestamp{referenceTime},
+				CreatedAt:         &Timestamp{referenceTime},
+				UpdatedAt:         &Timestamp{referenceTime},
 				ClosedBy:          &User{ID: Int64(1)},
 				URL:               String("url"),
 				HTMLURL:           String("hurl"),
