@@ -100,7 +100,7 @@ func TestUsersServiceReason_Suspend(t *testing.T) {
 
 	mux.HandleFunc("/users/u/suspended", func(w http.ResponseWriter, r *http.Request) {
 		v := new(UserSuspendOptions)
-		json.NewDecoder(r.Body).Decode(v)
+		assertNilError(t, json.NewDecoder(r.Body).Decode(v))
 
 		testMethod(t, r, "PUT")
 		if !cmp.Equal(v, input) {
@@ -142,3 +142,17 @@ func TestUsersService_Unsuspend(t *testing.T) {
 		return client.Users.Unsuspend(ctx, "u")
 	})
 }
+
+func TestUserSuspendOptions_Marshal(t *testing.T) {
+	testJSONMarshal(t, &UserSuspendOptions{}, "{}")
+
+	u := &UserSuspendOptions{
+		Reason: String("reason"),
+	}
+
+	want := `{
+		"reason": "reason"
+	}`
+
+	testJSONMarshal(t, u, want)
+}
