@@ -84,8 +84,8 @@ func TestUser_Marshal(t *testing.T) {
 		SuspendedAt:             &Timestamp{referenceTime},
 		Type:                    String("test type"),
 		SiteAdmin:               Bool(false),
-		TotalPrivateRepos:       Int(2),
-		OwnedPrivateRepos:       Int(1),
+		TotalPrivateRepos:       Int64(2),
+		OwnedPrivateRepos:       Int64(1),
 		PrivateGists:            Int(1),
 		DiskUsage:               Int(1),
 		Collaborators:           Int(1),
@@ -94,7 +94,7 @@ func TestUser_Marshal(t *testing.T) {
 			Name:          String("silver"),
 			Space:         Int(1024),
 			Collaborators: Int(10),
-			PrivateRepos:  Int(4),
+			PrivateRepos:  Int64(4),
 			FilledSeats:   Int(24),
 			Seats:         Int(1),
 		},
@@ -252,7 +252,7 @@ func TestUsersService_Edit(t *testing.T) {
 
 	mux.HandleFunc("/user", func(w http.ResponseWriter, r *http.Request) {
 		v := new(User)
-		json.NewDecoder(r.Body).Decode(v)
+		assertNilError(t, json.NewDecoder(r.Body).Decode(v))
 
 		testMethod(t, r, "PATCH")
 		if !cmp.Equal(v, input) {
