@@ -25,17 +25,12 @@ import (
 	"reflect"
 	"strings"
 
-	"github.com/google/go-github/v48/github"
-	"golang.org/x/oauth2"
+	"github.com/google/go-github/v60/github"
 )
 
 var (
 	client *github.Client
 
-	// auth indicates whether tests are being run with an OAuth token.
-	// Tests can use this flag to skip certain tests when run without auth.
-	auth bool
-
 	skipURLs = flag.Bool("skip_urls", false, "skip url fields")
 )
 
@@ -47,11 +42,7 @@ func main() {
 		print("!!! No OAuth token. Some tests won't run. !!!\n\n")
 		client = github.NewClient(nil)
 	} else {
-		tc := oauth2.NewClient(context.Background(), oauth2.StaticTokenSource(
-			&oauth2.Token{AccessToken: token},
-		))
-		client = github.NewClient(tc)
-		auth = true
+		client = github.NewClient(nil).WithAuthToken(token)
 	}
 
 	for _, tt := range []struct {
